@@ -9,8 +9,8 @@ class CategoricalDataExchange: public IDataExchange
 {
   public:
     CategoricalDataExchange(){};
-    virtual void Output(Rcpp::S4& obj,ICoClustModel*,bool);
-    virtual void DataInput(Rcpp::S4 & obj);
+    virtual void dataOutput(Rcpp::S4& obj,ICoClustModel*,bool);
+    virtual void dataInput(Rcpp::S4 & obj);
     virtual void instantiateModel(ICoClustModel*& model);
     inline const MatrixInteger& GetData() const {return m_Dataij_;}
     virtual ~CategoricalDataExchange(){};
