@@ -37,12 +37,12 @@
 #include "coclust/src/Models/ContinuousLBModel.h"
 #include "coclust/src/Models/ContinuousLBModelequalsigma.h"
 
-void ContinuousDataExchange::Output(Rcpp::S4& obj,ICoClustModel* model,bool successful)
+void ContinuousDataExchange::dataOutput(Rcpp::S4& obj,ICoClustModel* model,bool successful)
 {
   if(!successful)
   {
     obj.slot("successful") = false;
-    obj.slot("message") = model->GetErrormsg();
+    obj.slot("message") = std::string("Co-Clustering Failed! ") + model->errorMsg();
   }
   else
   {
@@ -55,52 +55,57 @@ void ContinuousDataExchange::Output(Rcpp::S4& obj,ICoClustModel* model,bool succ
     {
       case pik_rhol_sigma2kl:
          ptrLBM = dynamic_cast<ContinuousLBModel*>(model);
-        obj.slot("classmean") = convertMatrix<Rcpp::NumericMatrix,MatrixReal>(ptrLBM->GetMean());
-        obj.slot("classvariance") = convertMatrix<Rcpp::NumericMatrix,MatrixReal>(ptrLBM->GetSigma());
-        obj.slot("coclusterdata") = convertMatrix<Rcpp::NumericMatrix,MatrixReal>(ptrLBM->GetArrangedDataClusters());
+        obj.slot("classmean") = STK::wrap(ptrLBM->mean());
+        obj.slot("classvariance") = STK::wrap(ptrLBM->sigma2());
+        obj.slot("coclusterdata") = STK::wrap(ptrLBM->arrangedDataClusters());
         break;
       case pik_rhol_sigma2:
         ptrLBMeq = dynamic_cast<ContinuousLBModelequalsigma*>(model);
-        variance = ptrLBMeq->GetSigma()*MatrixReal::Ones(Mparam_.nbrowclust_,Mparam_.nbcolclust_);
-        obj.slot("classmean") = convertMatrix<Rcpp::NumericMatrix,MatrixReal>(ptrLBMeq->GetMean());
-        obj.slot("classvariance") = convertMatrix<Rcpp::NumericMatrix,MatrixReal>(variance);
-        obj.slot("coclusterdata") = convertMatrix<Rcpp::NumericMatrix,MatrixReal>(ptrLBMeq->GetArrangedDataClusters());
+        variance = ptrLBMeq->sigma2()*STK::Const::Array<STK::Real>(Mparam_.nbrowclust_,Mparam_.nbcolclust_);
+        obj.slot("classmean") = STK::wrap(ptrLBMeq->mean());
+        obj.slot("classvariance") = STK::wrap(variance);
+        obj.slot("coclusterdata") = STK::wrap(ptrLBMeq->arrangedDataClusters());
         break;
       case pi_rho_sigma2kl:
         ptrLBM = dynamic_cast<ContinuousLBModel*>(model);
-        obj.slot("classmean") = convertMatrix<Rcpp::NumericMatrix,MatrixReal>(ptrLBM->GetMean());
-        obj.slot("classvariance") = convertMatrix<Rcpp::NumericMatrix,MatrixReal>(ptrLBM->GetSigma());
-        obj.slot("coclusterdata") = convertMatrix<Rcpp::NumericMatrix,MatrixReal>(ptrLBM->GetArrangedDataClusters());
+        obj.slot("classmean") = STK::wrap(ptrLBM->mean());
+        obj.slot("classvariance") = STK::wrap(ptrLBM->sigma2());
+        obj.slot("coclusterdata") = STK::wrap(ptrLBM->arrangedDataClusters());
         break;
       case pi_rho_sigma2:
         ptrLBMeq = dynamic_cast<ContinuousLBModelequalsigma*>(model);
-        variance = ptrLBMeq->GetSigma()*MatrixReal::Ones(Mparam_.nbrowclust_,Mparam_.nbcolclust_);
-        obj.slot("classmean") = convertMatrix<Rcpp::NumericMatrix,MatrixReal>(ptrLBMeq->GetMean());
-        obj.slot("classvariance") = convertMatrix<Rcpp::NumericMatrix,MatrixReal>(variance);
-        obj.slot("coclusterdata") = convertMatrix<Rcpp::NumericMatrix,MatrixReal>(ptrLBMeq->GetArrangedDataClusters());
+        variance = ptrLBMeq->sigma2()*STK::Const::Array<STK::Real>(Mparam_.nbrowclust_,Mparam_.nbcolclust_);
+        obj.slot("classmean") = STK::wrap(ptrLBMeq->mean());
+        obj.slot("classvariance") = STK::wrap(variance);
+        obj.slot("coclusterdata") = STK::wrap(ptrLBMeq->arrangedDataClusters());
+        break;
+      default:
+        Rcpp::stop("Wrong Model in ContinuousDataExchange. Please report Bug.");
         break;
     }
 
-    obj.slot("rowclass") = convertvector<Rcpp::IntegerVector,VectorInteger>(model->GetRowClassificationVector());
-    obj.slot("colclass") = convertvector<Rcpp::IntegerVector,VectorInteger>(model->GetColumnClassificationVector());
-    obj.slot("rowproportions") = convertvector<Rcpp::NumericVector,VectorReal>(model->GetRowProportions());
-    obj.slot("columnproportions") = convertvector<Rcpp::NumericVector,VectorReal>(model->GetColProportions());
-    obj.slot("rowposteriorprob") = convertMatrix<Rcpp::NumericMatrix,MatrixReal>(model->GetRowPosteriorprob());
-    obj.slot("colposteriorprob") = convertMatrix<Rcpp::NumericMatrix,MatrixReal>(model->GetColPosteriorprob());
-    obj.slot("likelihood") = model->GetLikelihood();
+    obj.slot("rowclass") = STK::wrap(model->rowClassificationVector());
+    obj.slot("colclass") = STK::wrap(model->columnClassificationVector());
+    obj.slot("rowproportions") = STK::wrap(model->rowProportions());
+    obj.slot("columnproportions") = STK::wrap(model->colProportions());
+    obj.slot("rowposteriorprob") = STK::wrap(model->rowPosteriorProb());
+    obj.slot("colposteriorprob") = STK::wrap(model->colPosteriorProb());
+    obj.slot("likelihood") = model->likelihood();
   }
 }
 
-void ContinuousDataExchange::DataInput(Rcpp::S4 & obj)
+void ContinuousDataExchange::dataInput(Rcpp::S4 & obj)
 {
-  Rcpp::NumericMatrix data(SEXP(obj.slot("data")));
-  convertMatrix<Rcpp::NumericMatrix,MatrixReal>(data,m_Dataij_);
-  Mparam_.nbrowdata_ = m_Dataij_.rows();
-  Mparam_.nbcoldata_ = m_Dataij_.cols();
+  STK::RMatrix<STK::Real> data(SEXP(obj.slot("data")));
+  m_Dataij_ = data;
+  Mparam_.nbrowdata_ = m_Dataij_.sizeRows();
+  Mparam_.nbcoldata_ = m_Dataij_.sizeCols();
 }
 
-void ContinuousDataExchange::instantiateModel(ICoClustModel*& model){
-  if(!strategy_.SemiSupervised){
+void ContinuousDataExchange::instantiateModel(ICoClustModel*& model)
+{
+  if(!strategy_.SemiSupervised)
+  {
     switch (strategy_.Model_)
     {
       case pik_rhol_sigma2kl:
@@ -119,8 +124,13 @@ void ContinuousDataExchange::instantiateModel(ICoClustModel*& model){
         Mparam_.fixedproportions_ =true;
         model = new ContinuousLBModelequalsigma(m_Dataij_,Mparam_);
         break;
+      default:
+        Rcpp::stop("Wrong Model in ContinuousDataExchange. Please report Bug.");
+        break;
     }
-  }else{
+  }
+  else
+  {
     switch (strategy_.Model_)
     {
       case pik_rhol_sigma2kl:
@@ -139,6 +149,9 @@ void ContinuousDataExchange::instantiateModel(ICoClustModel*& model){
         Mparam_.fixedproportions_ =true;
         model = new ContinuousLBModelequalsigma(m_Dataij_,v_rowlabels_,v_collabels_,Mparam_);
         break;
+      default:
+        Rcpp::stop("Wrong Model in ContinuousDataExchange. Please report Bug.");
+        break;
     }
   }
 }
