@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------*/
-/*     Copyright (C) 2011-2013  Parmeet Singh Bhatia
+/*     Copyright (C) 2011-2015  <MODAL team @INRIA,Lille & U.M.R. C.N.R.S. 6599 Heudiasyc, UTC>
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as
@@ -46,6 +46,6 @@ class RandomInit: public IInit
 
 inline bool RandomInit::run()
 {
-  return p_Model_->RandomInit();
+  return p_Model_->randomInit();
 }
 #endif /* RANDOMINIT_H_ */
